<!DOCTYPE HTML>
<html lang="en">
    <head>
        <title>AutoGrader</title>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <link rel="stylesheet" type="text/css" href="../lib/css/bootstrap.min.css" />
        <link rel="stylesheet" type="text/css" href="../css/general_styles.css" />
        <script src="../lib/js/popper.min.js"></script>
        <script src="../lib/js/jquery-3.6.0.min.js"></script>
        <script src="../lib/js/bootstrap.min.js"></script>
        <script type="text/javascript" src="/eel.js"></script>
        <script type="text/javascript" src="../js/base.js"></script>
        {% block head %}{% endblock %}
        <script type="text/javascript" src="../js/callbacks.js"></script>
        <link rel="stylesheet" type="text/css" href="../lib/fontawesome/css/all.min.css" />
    </head>

    <body>
        {% block content %}{% endblock %}
    </body>

</html>
