/* 

/* Generals and Fonts */

*{
    margin: 0px;
    padding: 0px;
    line-height: 1.0;
}

html,body{
    height: 100%;

}

body{
    display: flex;
    flex-direction: column;
}

@font-face {
    font-family: 'humanist';
    src: url('../lib/fonts/humanist.ttf') format('truetype');
    font-weight: normal;
    font-style: normal;
}

/* Checkbox  Section */ 

.check_box {
    display:none;
}

label{
    vertical-align: middle;
}

.checkbox-containers{
    z-index: 100;
    position: relative;
    margin-top: 10px;
}

.checkbox-container{
    margin-bottom: 5px;
}

.check_box + label{
    background: url('../images/checkbox-unchecked.png') no-repeat;
    height: 32px;
    width: 32px;
    display:inline-block;
    padding: 0px 0px 0px 0px;
}

.check_box:checked + label{
    background: url('../images/checkbox-checked.png') no-repeat;
    height: 32px;
    width: 32px;
    display:inline-block;
    padding: 0px 0px 0px 0px;
}

.checkbox_label{
    display:inline;
}

.drop-zone-input{
    display: none;
}

.drop-zone--over{
    border-style: dotted;
}

.file-container{
    position:absolute;
    right: 0px;
    padding-right: 10px;
}

p{
    margin-bottom: 0px;
}



.cfgtooltip + .tooltiptext {
    display: none;
    position: absolute;
    z-index: 99999;
    min-width: 300px;
    right: 20%;

    background-color: black;
    color: #fff;
    text-align: center;
    vertical-align: middle;
    padding: 5px 0px;
    border-radius: 6px;
  }
  
.d-inline-table {
    display: inline-table!important;
}