{% extends 'base.html' %}
{% block head %}
<link rel="stylesheet" type="text/css" href="../css/index.css" />
{% endblock %}

{% block content %}
<div class="header">
    <a href="plagiarism-configuration1.html" class="plagiarism-container">
        <img src="../images/button_bg_top.png" />
        <p>Plagiarism</p>
    </a>

</div>

<div class="assignment-container"
    onclick="eel.extract_assignment()(r => {if (r) location.href = 'assignment-configuration.html'});">
    <img src="../images/Assignment_background_small.png" />
    <p>Assignment</p>
    <input class="drop-zone-input" />
</div>


<div class="footer" style="cursor: pointer;">
    <a class="create-assignment-container"
    onclick="eel.create_assignment()(r => {if (r) location.href = 'assignment-configuration.html'});">
        <img src="../images/create_assignment_bg_orig.png" />
        <p>Create Assignment</p>
    </a>
</div>
{% endblock %}
