
/* Checkbox  Section */ 
.check_box {
    display:none;
}

label{
    vertical-align: middle;
}

.checkbox-containers{
    z-index: 100;
    position: relative;
    margin-top: 10px;
    overflow: auto;
    height:400px;
}

.checkbox-container{
    margin-bottom: 5px;
}

.check_box + label{
    background:'../images/checkbox-unchecked.png' no-repeat;
    height: 32px;
    width: 32px;
    display:inline-block;
    padding: 0 0 0 0px;
}

.check_box:checked + label{
    background:'../images/checkbox-checked.png' no-repeat;
    height: 32px;
    width: 32px;
    display:inline-block;
    padding: 0 0 0 0px;
}

.checkbox_label{
    display:inline;
}

/* Assignement Configuration Button */

.header{
    position: relative;
    height:100px;
    width:100%;
    background-color: white;
}

.assignment-configuration-container{
    position: absolute;
    left:5px;
    top:5px;
}

.assignment-configuration-container .assignment-configuration-text {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:107px;
    top:45px;
    transform:translate(-50%, -50%);
}

.assignment-configuration-container p{
    line-height:0.6;

}


/* Main Container Section */

.main-container{
    display: flex;
    align-items: center;
    justify-content: center;
    margin-top:50px;
}

.upload-container{
    position: relative;
    margin-right: 50px;
    cursor: pointer;
}

.upload-container p {
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    padding-bottom: 25px;
}

#homework-container{
    position: relative;
    width:368px;
    height:500px;
    border:1px solid black;
    margin-right: 50px;
    padding-right: 5px;
    border-radius: 15px;
    box-shadow: 5px 10px 5px #ccc;
}

#homework-container p{
    text-align: center;
    font-weight: bold;
}

#homework-container img{
    width:350px;
    height:46.9px;
}

.homework-title{
    position: absolute;
    color:white;
    left:50%;
    transform: translateX(-50%);
    font-size: 30px;
}

#homework-container .add-item{
    position: absolute;
    bottom:5px;
    right:7px;
    color: #00A9E9;

}

#no-items-container{
    display: none;
}

.add-item{
    color:#00A9E9;
    cursor: pointer;
}

#homework-container .buttons{
    text-align: right;
}

/* Footer   */

.footer{
   
    position: relative;
    height:100px;
    margin-top: auto;
}

.right-button-container{
    position: absolute;
    bottom:5px;
    right:5px;
    cursor: pointer;
}

.right-button-container p {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    margin-right: 20px;
}

.table-scroll{
    height:440px;
    overflow-y: auto;
    overflow-x: hidden;
}

.table-scroll::-webkit-scrollbar{
    display: none;
}

.table-hover tbody tr:hover td, .table-hover tbody tr:hover th {
    background-color: #e5f4fa;
    
}

.show-window{
    display: block !important;
}
