
/* Generals and Fonts */

table{
    border-collapse: collapse;
    border:1px solid #009de0;
    width:100%;
}

th{
    padding-right: 50px;
    padding-left: 5px;
    font-size: 25px;
    background-color: #009de0;
    color:white;   
}

td{
    text-align: center;
    border:2px solid #009de0;
    padding:5px 0px;
    font-size: 18px;
}


/* plagiarism Button */

.header{
    position: relative;
    height:100px;
    width:100%;
    
    background-color: white;
}

.plagiarism-container{
    position: absolute;
    left:5px;
    top:5px;
}

.plagiarism-container p {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    
    margin-right: 20px;
}

/* Assignment Button */

.assignment-container{
    
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    cursor:pointer;
 
}

.assignment-container p{
    position: absolute;
    font-family: 'humanist';
    font-size: 33px;
    color:white;
  
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    padding-bottom: 30px;
}

/* Create Assignment Button*/

.footer{
   
    position: relative;
    height:100px;
    margin-top: auto;
}

.create-assignment-container{
    position: absolute;
    bottom:5px;
    right:5px;
}

.create-assignment-container p {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    margin-right: 20px;
}


