{% extends 'base.html' %}

{% block head %}
<link rel="stylesheet" href="../css/grading-results.css" />
{% endblock %}

{% block content %}
<div class="header">
    <a class="grading-configuration-container" href="homework.html">
        <img src="../images/header-bg-long.png" />
        <div class="grading-configuration-text">
            <p>Homework</p>
        </div>
    </a>
</div>

<div style="display:flex; align-items: center; justify-content: center;">

    <div class="main-container">

        <div class="loading-text">
            <div class="spinner-border text-dark" role="status">
                <span class="sr-only">Loading...</span>
              </div>
            <h1 style="display: inline-block;">Loading...</h1>

        </div>

        <div class="table-scroll table table-hover">
            <table class="table-content">

            </table>
        </div>
    </div>
</div>

<!--Footer -->
<div class="footer">
    <a class="grading-container" onclick="eel.export_grading_results()" style="cursor: pointer;">
        <img src="../images/create_assignment_bg_export.png" />
        <p>Export</p>
    </a>
</div>

<script src="../js/gradingResults.js"></script>

{% endblock %}
