
table{
    border-collapse: collapse;
    width:100%;
}

th{
    font-size: 25px;
    background-color: #009de0;
    color:white;
    text-align: center;
}

td{
    text-align: center;
    border:1px solid #009de0;
    font-size: 18px;
}

.table{
    margin-bottom:0 !important;
}

.table th{
    border:1px solid #009de0 !important;
}

thead th{
    position: sticky; 
    top: 0; 
    z-index: 2;
}


/* Grading Configuration Button */

.header{
    position: relative;
    height:100px;
    width:100%;
    background-color: white;
}

.grading-configuration-container{
    position: absolute;
    left:5px;
    top:5px;
}

.grading-configuration-text {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    padding-right:70px;
}


/* Table */

.container{
    display: flex;
    margin-top:50px;
    width:100%;
    background-color: white;
    justify-content: center;
}

.main-container{
    position: relative;
    width:1000px;
    height: 600px;
    margin-top: 20px;
    border:3px solid dodgerblue;
}

.table-scroll{
    height:594px;
    overflow-y: auto;
    overflow-x: auto;
}


.table-hover tbody tr:hover td, .table-hover tbody tr:hover th {
    background-color: #e5f4fa;
    
}

/* Export Button */

.export-container{
    position: absolute;
    bottom:5px;
    left:5px;
    cursor:pointer;
}

.export-container p {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    padding-right:20px;
}


/* Grading Button */

.grading-container{
    position: absolute;
    bottom:5px;
    right:5px;
}

.grading-container p {
    color:white;
    font-family: 'humanist';
    font-size: 33px;
    position: absolute;
    left:50%;
    top:50%;
    transform:translate(-50%, -50%);
    padding-left:30px;
    
}

/* Loading Text */
.loading-text{
    position: absolute;
    top:50%;
    left:50%;
    transform: translate(-50%,-50%);
    display: none;
}


